=========================
jrtzcloud-python-sdk-core
=========================


This is the core module of JrtzCloud Python SDK.

JrtzCloud Python SDK is the official software development kit. It makes things easy to integrate your Python application,
library, or script with JrtzCloud services.

This module works on Python versions:

   * 2.6.5 and greater


Documentation:

Please visit https://help.test.investoday.net/